/*
  Axis Joystick, Multiple Reading

  Reads a press of the joystick and displays information
  in the default Serial.

  Multiple reading of the joystick controller.
  If the joystick is clamped,
  returns a pressed button value.
  Return value of pressing the remote control:
    Move::PRESS - button is pressed;
    Move::UP - X axis is pressed up;
    Move::DOWN - X axis is pressed down;
    Move::RIGTH - Y axis is pressed right;
    Move::LEFT - Y axis is pressed left;
    Move::NOT - not pressed.

  https://github.com/YuriiSalimov/AxisJoystick

  Created by Yurii Salimov, February, 2018.
  Released into the public domain.
*/
#include <AxisJoystick.h>

#define SW_PIN 5
#define VRX_PIN A1
#define VRY_PIN A2

Joystick* joystick;

// the setup function runs once when you press reset or power the board
void setup() {
  Serial.begin(9600);
  joystick = new AxisJoystick(SW_PIN, VRX_PIN, VRY_PIN);
}

// the loop function runs over and over again forever
void loop() {
  Serial.print("Joystick, Multiple Reading: ");
  Serial.println(moveTitle(joystick->multipleRead()));
  delay(500); // To delay the output of information.
}

/**
  Return title of the input joystick move.
*/
String moveTitle(const Joystick::Move move) {
  if (move == Joystick::Move::NOT) {
    return "NOT";
  } else if (move == Joystick::Move::PRESS) {
    return "PRESS";
  } else if (move == Joystick::Move::UP) {
    return "UP";
  } else if (move == Joystick::Move::DOWN) {
    return "DOWN";
  } else if (move == Joystick::Move::RIGHT) {
    return "RIGHT";
  } else if (move == Joystick::Move::LEFT) {
    return "LEFT";
  } else {
    return "???";
  }
}
